==> hs-mtl-2.0.1.0.tgz: lib/ghc/mtl-2.0.1.0/register.sh <==
#!/bin/sh
echo 'name: mtl
version: 2.0.1.0
id: mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2

license: BSD3
copyright:
maintainer: libraries@haskell.org
stability:
homepage:
package-url:
description: Monad classes using functional dependencies, with instances
             for various monad transformers, inspired by the paper
             /Functional Programming with Overloading and Higher-Order Polymorphism/,
             by Mark P Jones, in /Advanced School of Functional Programming/, 1995
             (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
category: Control
author: Andy Gill
pkgpath: devel/hs-mtl
exposed: True
exposed-modules: Control.Monad.Cont Control.Monad.Cont.Class
                 Control.Monad.Error Control.Monad.Error.Class
                 Control.Monad.Identity Control.Monad.List Control.Monad.RWS
                 Control.Monad.RWS.Class Control.Monad.RWS.Lazy
                 Control.Monad.RWS.Strict Control.Monad.Reader
                 Control.Monad.Reader.Class Control.Monad.State
                 Control.Monad.State.Class Control.Monad.State.Lazy
                 Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
                 Control.Monad.Writer.Class Control.Monad.Writer.Lazy
                 Control.Monad.Writer.Strict
hidden-modules:
import-dirs: /usr/local/lib/ghc/mtl-2.0.1.0
library-dirs: /usr/local/lib/ghc/mtl-2.0.1.0
hs-libraries: HSmtl-2.0.1.0
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.3.1.0-912d55d387093f740e3bcd2ffbf1dd83
         transformers-0.2.2.0-a8a2dbba7d96131db605cf631ea0c8c4
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-mtl-2.0.1.0/html/mtl.haddock
haddock-html: /usr/local/share/doc/hs-mtl-2.0.1.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-mtl-2.1.2p0.tgz: lib/ghc/mtl-2.1.2/register.sh <==
#!/bin/sh
echo 'name: mtl
version: 2.1.2
id: mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29

license: BSD3
copyright:
maintainer: Edward Kmett <ekmett@gmail.com>
stability:
homepage: http://github.com/ekmett/mtl
package-url:
synopsis: Monad classes, using functional dependencies
description: Monad classes using functional dependencies, with instances
             for various monad transformers, inspired by the paper
             /Functional Programming with Overloading and Higher-Order Polymorphism/,
             by Mark P Jones, in /Advanced School of Functional Programming/, 1995
             (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
category: Control
author: Andy Gill
pkgpath: devel/hs-mtl
exposed: True
exposed-modules: Control.Monad.Cont Control.Monad.Cont.Class
                 Control.Monad.Error Control.Monad.Error.Class
                 Control.Monad.Identity Control.Monad.List Control.Monad.RWS
                 Control.Monad.RWS.Class Control.Monad.RWS.Lazy
                 Control.Monad.RWS.Strict Control.Monad.Reader
                 Control.Monad.Reader.Class Control.Monad.State
                 Control.Monad.State.Class Control.Monad.State.Lazy
                 Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
                 Control.Monad.Writer.Class Control.Monad.Writer.Lazy
                 Control.Monad.Writer.Strict
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/mtl-2.1.2
library-dirs: /usr/local/lib/ghc/mtl-2.1.2
hs-libraries: HSmtl-2.1.2
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
         transformers-0.3.0.0-8e66ecc7d4dae2b07b2b5406908c70e4
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-mtl-2.1.2/html/mtl.haddock
haddock-html: /usr/local/share/doc/hs-mtl-2.1.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
